@@ -45,8 +45,9 @@ import re
 import cmd
 import optparse
 import sys
+import time
 from pprint import pprint
-from datetime import date
+from datetime import datetime
 
 # this is python 2.x style
 def introspect_handler_2(handler):
@@ -96,6 +97,9 @@ _NOT_SPECIFIED = ("Not", "Specified")
 _INCORRECT_NUM_ARGS_RE = re.compile(
     r"(takes [\w ]+ )(\d+)( arguments? \()(\d+)( given\))")
 
+_INCORRECT_NUM_ARGS_RE_PY3 = re.compile(
+    r"(missing\s+\d+.*)")
+
 # Static bits of man page
 MAN_HEADER = r""".TH %(ucname)s "1" "%(date)s" "%(name)s %(version)s" "User Commands"
 .SH NAME
@@ -619,16 +623,17 @@ class RawCmdln(cmd.Cmd):
         usage:
             ${name} man
         """
-        self.stdout.write(bytes(
+        mandate = datetime.utcfromtimestamp(int(os.environ.get('SOURCE_DATE_EPOCH', time.time())))
+        self.stdout.write(
             self.man_header % {
-                'date': date.today().strftime('%b %Y'),
+                'date': mandate.strftime('%b %Y'),
                 'version': self.get_version(),
                 'name': self.name,
                 'ucname': self.name.upper()
-                },
-            "utf-8"))
+                }
+            )
 
-        self.stdout.write(bytes(self.man_commands_header, "utf-8"))
+        self.stdout.write(self.man_commands_header)
         commands = self._help_get_command_list()
         for command, doc in commands:
             cmdname = command.split(' ')[0]
@@ -639,14 +644,14 @@ class RawCmdln(cmd.Cmd):
                     line = line[8:]
                 lines.append(man_escape(line))
 
-            self.stdout.write(bytes(
-                '.TP\n\\fB%s\\fR\n%s\n' % (command, '\n'.join(lines)), "utf-8"))
+            self.stdout.write(
+                '.TP\n\\fB%s\\fR\n%s\n' % (command, '\n'.join(lines)))
 
-        self.stdout.write(bytes(self.man_options_header, "utf-8"))
-        self.stdout.write(bytes(
-            man_escape(self._help_preprocess('${option_list}', None)), "utf-8"))
+        self.stdout.write(self.man_options_header)
+        self.stdout.write(
+            man_escape(self._help_preprocess('${option_list}', None)))
 
-        self.stdout.write(bytes(self.man_footer, "utf-8"))
+        self.stdout.write(self.man_footer)
 
         self.stdout.flush()
 
@@ -891,7 +896,7 @@ class RawCmdln(cmd.Cmd):
                 warnings.warn("argument '**%s' on '%s.%s' command "
                               "handler will never get values"
                               % (name, self.__class__.__name__,
-                                 getattr(func_defaults, "__name__", getattr(func_defaults, "func_name"))))
+                                 getattr(func, "__name__", getattr(func, "func_name"))))
             if co_flags & CO_FLAGS_ARGS:
                 name = argnames.pop(-1)
                 tail = "[%s...]" % name.upper()
@@ -1244,6 +1249,7 @@ class Cmdln(RawCmdln):
                     raise
                 msg = ex.args[0]
                 match = _INCORRECT_NUM_ARGS_RE.search(msg)
+                match_py3 = _INCORRECT_NUM_ARGS_RE_PY3.search(msg)
                 if match:
                     msg = list(match.groups())
                     msg[1] = int(msg[1]) - 3
@@ -1252,6 +1258,8 @@ class Cmdln(RawCmdln):
                     msg[3] = int(msg[3]) - 3
                     msg = ''.join(map(str, msg))
                     raise CmdlnUserError(msg)
+                elif match_py3:
+                    raise CmdlnUserError(match_py3.group(1))
                 else:
                     raise
         else:
