@@ -13,12 +13,12 @@ import sys
 import inspect
 
 try:
-    from urllib.parse import urlparse, splithost, splitport, splittype
+    from urllib.parse import urlparse, splithost, splitport, splittype, urldefrag
     from urllib.request import addinfourl
     from http.client import HTTPSConnection
 except ImportError:
     #python 2.x
-    from urlparse import urlparse
+    from urlparse import urlparse, urldefrag
     from urllib import addinfourl, splithost, splitport, splittype
     from httplib import HTTPSConnection
 
@@ -199,13 +199,13 @@ class myHTTPSHandler(M2Crypto.m2urllib2.HTTPSHandler):
 
         if target_host != host:
             request_uri = urldefrag(full_url)[0]
-            h = httpslib.ProxyHTTPSConnection(host=host, ssl_context=self.ctx)
+            h = myProxyHTTPSConnection(host=host, appname=self.appname, ssl_context=self.ctx)
         else:
             try:     # up to python-3.2
                 request_uri = req.get_selector()
             except AttributeError:  # from python-3.3
                 request_uri = req.selector
-            h = httpslib.HTTPSConnection(host=host, ssl_context=self.ctx)
+            h = myHTTPSConnection(host=host, appname=self.appname, ssl_context=self.ctx)
         # End our change
         h.set_debuglevel(self._debuglevel)
 
