@@ -1,7 +1,8 @@
-#!/usr/bin/python
-
 class NoSecureSSLError(Exception):
     def __init__(self, msg):
+        Exception.__init__(self)
         self.msg = msg
     def __str__(self):
         return self.msg
+
+# vim: sw=4 et
